@@ -28,7 +28,8 @@ window.baguetteBox = (function () {
         isOverlayVisible = false,
         touch = {},  // start-pos
         touchFlag = false,  // busy
-        regex = /.+\.(gif|jpe?g|png|webp)/i,
+        re_i = /.+\.(gif|jpe?g|png|webp)(\?|$)/i,
+        re_v = /.+\.(webm|mp4)(\?|$)/i,
         data = {},  // all galleries
         imagesElements = [],
         documentLastFocus = null;
@@ -96,10 +97,6 @@ window.baguetteBox = (function () {
         data[selector] = selectorData;
 
         [].forEach.call(galleryNodeList, function (galleryElement) {
-            if (userOptions && userOptions.filter) {
-                regex = userOptions.filter;
-            }
-
             var tagsNodeList = [];
             if (galleryElement.tagName === 'A') {
                 tagsNodeList = [galleryElement];
@@ -109,7 +106,7 @@ window.baguetteBox = (function () {
 
             tagsNodeList = [].filter.call(tagsNodeList, function (element) {
                 if (element.className.indexOf(userOptions && userOptions.ignoreClass) === -1) {
-                    return regex.test(element.href);
+                    return re_i.test(element.href) || re_v.test(element.href);
                 }
             });
             if (tagsNodeList.length === 0) {
@@ -209,24 +206,36 @@ window.baguetteBox = (function () {
         bindEvents();
     }
 
-    function keyDownHandler(event) {
-        switch (event.keyCode) {
-            case 37: // Left
-                showPreviousImage();
-                break;
-            case 39: // Right
-                showNextImage();
-                break;
-            case 27: // Esc
-                hideOverlay();
-                break;
-            case 36: // Home
-                showFirstImage(event);
-                break;
-            case 35: // End
-                showLastImage(event);
-                break;
-        }
+    function keyDownHandler(e) {
+        if (e.ctrlKey || e.altKey || e.metaKey || e.isComposing)
+            return;
+
+        var k = e.code + '';
+
+        if (k == "ArrowLeft" || k == "KeyJ")
+            showPreviousImage();
+        else if (k == "ArrowRight" || k == "KeyL")
+            showNextImage();
+        else if (k == "Escape")
+            hideOverlay();
+        else if (k == "Home")
+            showFirstImage(e);
+        else if (k == "End")
+            showLastImage(e);
+        else if (k == "Space" || k == "KeyP" || k == "KeyK")
+            playpause();
+        else if (k == "KeyU" || k == "KeyO")
+            relseek(k == "KeyU" ? -10 : 10);
+    }
+
+    function keyUpHandler(e) {
+        if (e.ctrlKey || e.altKey || e.metaKey || e.isComposing)
+            return;
+
+        var k = e.code + '';
+
+        if (k == "Space")
+            ev(e);
     }
 
     var passiveSupp = false;
@@ -325,6 +334,7 @@ window.baguetteBox = (function () {
         }
 
         bind(document, 'keydown', keyDownHandler);
+        bind(document, 'keyup', keyUpHandler);
         currentIndex = chosenImageIndex;
         touch = {
             count: 0,
@@ -366,6 +376,7 @@ window.baguetteBox = (function () {
 
     function hideOverlay(e) {
         ev(e);
+        playvid(false);
         if (options.noScrollbars) {
             document.documentElement.style.overflowY = 'auto';
             document.body.style.overflowY = 'auto';
@@ -375,6 +386,7 @@ window.baguetteBox = (function () {
         }
 
         unbind(document, 'keydown', keyDownHandler);
+        unbind(document, 'keyup', keyUpHandler);
         // Fade out and hide the overlay
         overlay.className = '';
         setTimeout(function () {
@@ -398,8 +410,8 @@ window.baguetteBox = (function () {
             return;  // out-of-bounds or gallery dirty
         }
 
-        if (imageContainer.getElementsByTagName('img')[0]) {
-            // image is loaded, cb and bail
+        if (imageContainer.querySelector('img, video')) {
+            // was loaded, cb and bail
             if (callback) {
                 callback();
             }
@@ -408,7 +420,7 @@ window.baguetteBox = (function () {
 
         var imageElement = galleryItem.imageElement,
             imageSrc = imageElement.href,
-            thumbnailElement = imageElement.getElementsByTagName('img')[0],
+            thumbnailElement = imageElement.querySelector('img, video'),
             imageCaption = typeof options.captions === 'function' ?
                 options.captions.call(currentGallery, imageElement) :
                 imageElement.getAttribute('data-caption') || imageElement.title;
@@ -428,16 +440,20 @@ window.baguetteBox = (function () {
         }
         imageContainer.appendChild(figure);
 
-        var image = mknod('img');
-        image.onload = function () {
+        var is_vid = re_v.test(imageSrc),
+            image = mknod(is_vid ? 'video' : 'img');
+
+        clmod(imageContainer, 'vid', is_vid);
+
+        image.addEventListener(is_vid ? 'loadedmetadata' : 'load', function () {
             // Remove loader element
             var spinner = document.querySelector('#baguette-img-' + index + ' .baguetteBox-spinner');
             figure.removeChild(spinner);
-            if (!options.async && callback) {
+            if (!options.async && callback)
                 callback();
-            }
-        };
+        });
         image.setAttribute('src', imageSrc);
+        image.setAttribute('controls', 'controls');
         image.alt = thumbnailElement ? thumbnailElement.alt || '' : '';
         if (options.titleTag && imageCaption) {
             image.title = imageCaption;
@@ -498,6 +514,7 @@ window.baguetteBox = (function () {
             return false;
         }
 
+        playvid(false);
         currentIndex = index;
         loadImage(currentIndex, function () {
             preloadNext(currentIndex);
@@ -512,6 +529,26 @@ window.baguetteBox = (function () {
         return true;
     }
 
+    function vid() {
+        return imagesElements[currentIndex].querySelector('video');
+    }
+
+    function playvid(play) {
+        if (vid())
+            vid()[play ? 'play' : 'pause']();
+    }
+
+    function playpause() {
+        var v = vid();
+        if (v)
+            v[v.paused ? "play" : "pause"]();
+    }
+
+    function relseek(sec) {
+        if (vid())
+            vid().currentTime += sec;
+    }
+
     /**
      * Triggers the bounce animation
      * @param {('left'|'right')} direction - Direction of the movement
@@ -534,6 +571,8 @@ window.baguetteBox = (function () {
         } else {
             slider.style.transform = 'translate3d(' + offset + ',0,0)';
         }
+        playvid(false);
+        playvid(true);
     }
 
     function preloadNext(index) {
@@ -566,6 +605,7 @@ window.baguetteBox = (function () {
         unbindEvents();
         clearCachedData();
         unbind(document, 'keydown', keyDownHandler);
+        unbind(document, 'keyup', keyUpHandler);
         document.getElementsByTagName('body')[0].removeChild(ebi('baguetteBox-overlay'));
         data = {};
         currentGallery = [];
@@ -577,6 +617,8 @@ window.baguetteBox = (function () {
         show: show,
         showNext: showNextImage,
         showPrevious: showPreviousImage,
+        relseek: relseek,
+        playpause: playpause,
         hide: hideOverlay,
         destroy: destroyPlugin
     };
